@@ -1,10 +1,11 @@
 
 # robster/model.py LinearModel
 class LinearModel:
-  def __init__(self,feature_count, learning_rate, mean =0, std=0.003):
-    self.weight = np.random.normal(mean, std, [feature_count + 1, 1])
+  def __init__(self, feature_count, learning_rate, mean =0, std=0.003):
+    self.weight = np.random.normal(mean, std, [feature_count, 1])
     self.bias = np.zeros([1])
-    self.learning_rate = learning_rate
+    self.learning_rate_ = 0.003
+    # self.learning_rate_ = learning_rate
   
 
   def forward(self, X):
@@ -21,11 +22,11 @@ class LinearModel:
     return G_loss * g_loss_square * g_square_diff * g_diff_output
   
   def back(self, G_output, X):
-    G_w = np.matmul(G_output, X.transpose())
+    G_w = np.matmul(X.transpose(), G_output)
     G_b = np.sum(G_output, axis = 0)
 
-    self.weight -= self.learning_rate * G_w
-    self.bias -= self.learning_rate * G_b
+    self.weight -= self.learning_rate_ * G_w
+    self.bias -= self.learning_rate_ * G_b
 
 
   def forward_postproc(self, output, y):
