@@ -3,12 +3,12 @@ from robster.model import LinearModel
 
 class SingleLayerPerceptron:
   # def __init__(self, epochs, mini_batch, learning_rate = 3e-3, report = 1, MODEL = LinearModel):
-  def __init__(self, epochs, mini_batch, learning_rate = 3e-3, report = 1):
+  def __init__(self, epochs, mini_batch, report = 1, MODEL = LinearModel):
     self.epochs_ = epochs
     self.mini_batch_ = mini_batch
-    self.learning_rate_ = learning_rate
     self.report_=report
     self.MODEL_ = LinearModel
+    # self.learning_rate_ = learning_rate
 
 
   def fit(self, X, y):
@@ -16,6 +16,7 @@ class SingleLayerPerceptron:
     if str(type(y)) == "<class 'pandas.core.series.Series'>": y = y.to_numpy().reshape(-1,1)
 
     steps = int(X.shape[0])//self.mini_batch_ # 미니배치가 가능한 갯수
+    self.model = self.MODEL_(int(X.shape[1]))
     self.model = self.MODEL_(int(X.shape[1]), self.learning_rate_)
     # self.model = LinearModel(int(X.shape[1]), self.learning_rate_)
 
